.fb5 {
  flex-basis: 5%;
}
.fb10 {
  flex-basis: 10%;
}
.fb15 {
  flex-basis: 15%;
}
.fb20 {
  flex-basis: 20%;
}
.fb25 {
  flex-basis: 25%;
}
.fb30 {
  flex-basis: 30%;
}
.fb35 {
  flex-basis: 35%;
}
.fb40 {
  flex-basis: 40%;
}
.fb45 {
  flex-basis: 45%;
}
.fb50 {
  flex-basis: 50%;
}
.fb55 {
  flex-basis: 55%;
}
.fb60 {
  flex-basis: 60%;
}
.fb65 {
  flex-basis: 65%;
}
.fb70 {
  flex-basis: 70%;
}
.fb75 {
  flex-basis: 75%;
}
.fb80 {
  flex-basis: 80%;
}
.fb85 {
  flex-basis: 85%;
}
.fb90 {
  flex-basis: 90%;
}
.fb95 {
  flex-basis: 95%;
}
.reveal .ch10 pre code {
  max-height: calc(10 * var(--jp-code-font-size)) !important;
}
.reveal .ch11 pre code {
  max-height: calc(11 * var(--jp-code-font-size)) !important;
}
.reveal .ch12 pre code {
  max-height: calc(12 * var(--jp-code-font-size)) !important;
}
.reveal .ch13 pre code {
  max-height: calc(13 * var(--jp-code-font-size)) !important;
}
.reveal .ch14 pre code {
  max-height: calc(14 * var(--jp-code-font-size)) !important;
}
.reveal .ch15 pre code {
  max-height: calc(15 * var(--jp-code-font-size)) !important;
}
.reveal .ch16 pre code {
  max-height: calc(16 * var(--jp-code-font-size)) !important;
}
.reveal .ch17 pre code {
  max-height: calc(17 * var(--jp-code-font-size)) !important;
}
.reveal .ch18 pre code {
  max-height: calc(18 * var(--jp-code-font-size)) !important;
}
.reveal .ch19 pre code {
  max-height: calc(19 * var(--jp-code-font-size)) !important;
}
.reveal .ch20 pre code {
  max-height: calc(20 * var(--jp-code-font-size)) !important;
}
.reveal .ch21 pre code {
  max-height: calc(21 * var(--jp-code-font-size)) !important;
}
.reveal .ch22 pre code {
  max-height: calc(22 * var(--jp-code-font-size)) !important;
}
.reveal .ch23 pre code {
  max-height: calc(23 * var(--jp-code-font-size)) !important;
}
.reveal .ch24 pre code {
  max-height: calc(24 * var(--jp-code-font-size)) !important;
}
.reveal .ch25 pre code {
  max-height: calc(25 * var(--jp-code-font-size)) !important;
}
.reveal .ch26 pre code {
  max-height: calc(26 * var(--jp-code-font-size)) !important;
}
.reveal .ch27 pre code {
  max-height: calc(27 * var(--jp-code-font-size)) !important;
}
.reveal .ch28 pre code {
  max-height: calc(28 * var(--jp-code-font-size)) !important;
}
.reveal .ch29 pre code {
  max-height: calc(29 * var(--jp-code-font-size)) !important;
}
.reveal .ch30 pre code {
  max-height: calc(30 * var(--jp-code-font-size)) !important;
}
