/* Variables */
:root {
/* %VARIABLES% */
}
/* Custom Classes */
.centered,
.centered > p,
.centered > span {
  text-align: center !important;
}
.centered > * {
  display: block !important;
  font-size: x-large !important;
  margin: 1em auto !important;
}
.flex_slide {
  align-items: center;
  display: flex;
  justify-content: center;
  width: 100%;
}
.flex_main {
  flex: 1 1 80%;
}
.flex_aside {
  flex: 1 1 20%;
}
.flex_aside > *:not(:first-child) {
  margin-top: 2em;
}
.rounded_img {
  border-radius: var(--jnp-radius) !important;
}
/* Generic */
html,
body {
  background-attachment: var(--jnp-background-attachment) !important;
  background-color: var(--jnp-background-color) !important;
  background-image: var(--jnp-background-image) !important;
  background-position: var(--jnp-background-position) !important;
  background-repeat: var(--jnp-background-repeat) !important;
  background-size: var(--jnp-background-size) !important;
}
h1 {
  background-color: var(--jnp-main-color);
  border-radius: var(--jnp-radius) !important;
  color: var(--jnp-h1-color) !important;
  font-weight: bold !important;
  max-width: calc(100% - (2 * var(--jnp-radius))) !important;
  padding: var(--jnp-radius) !important;
}
h2 {
  color: var(--jnp-main-color) !important;
}
h2,
h3,
h4{
  margin: 1ch 0 0.5ch 0 !important;
}
a {
  color: var(--jnp-main-color) !important;
}
figure {
  margin: 0;
  padding: 0;
  text-align: center !important;
}
figure img {
  display: block;
  margin: 0 auto !important;
  padding: 0 !important;
  width: 100% !important;
}
figcaption {
  background-color: white;
  caption-side: bottom;
  display: block;
  font-size: 70%;
  margin: 0;
  padding: 0;
  width: 100%;
}
/* */
.slide {
  position: relative;
  width: auto;
}
.jp-MarkdownOutput .highlight,
.jp-MarkdownOutput .highlight pre {
  background-color: #f0f0f0 !important;
  border-radius: var(--jnp-radius) !important;
  border: none !important;
  box-shadow: none !important;
  margin: 0 0 1em 0 !important;
  max-width: calc(100% - (2 * var(--jnp-radius))) !important;
  padding: var(--jnp-radius) !important;
}
.jp-MarkdownOutput code {
  background-color: #f0f0f0 !important;
}
