body,
html {
  height: 100%;
  font-family: sans-serif;
}

body {
  display: flex;
  flex-direction: column;
  margin: 0;
}

#frame {
  margin: auto;
  max-width: 71ch;
  padding: 5ch;
}

#frame > img {
  width: 100%;
}
